# Ribasim API

`ribasim_api` is an extension to [xmipy](https://pypi.org/project/xmipy/) for the Ribasim API.

The `ribasim_api` can be used to access functionality in the eXtended Model Interface (XMI) wrapper (XmiWrapper)
and additional functionality specific to the Ribasim API.


`ribasim_api` can be installed by running

```
pip install ribasim-api
```

or

```
conda install -c conda-forge ribasim-api
```

# Contributing

For the developer docs please have a look at https://deltares.github.io/Ribasim/python/developer.html
